@@ -4,7 +4,7 @@ echo hello
 echo $?    # Exit status 0 returned because command executed successfully.
 
 lskdf      # Unrecognized command.
-echo $?    # Non-zero exit status returned because command failed to execute.
+echo $?    # Non-zero exit status returned -- command failed to execute.
 
 echo
 
@@ -13,3 +13,4 @@ exit 113   # Will return 113 to shell.
 
 #  By convention, an 'exit 0' indicates success,
 #+ while a non-zero exit value means an error or anomalous condition.
+#  See the "Exit Codes With Special Meanings" appendix.
