@@ -9,7 +9,7 @@ GetPersonalData ()
   read city 
   read state 
   read zipcode
-} # This certainly looks like an interactive function, but...
+} # This certainly appears to be an interactive function, but . . .
 
 
 # Supply input to the above function.
@@ -17,8 +17,8 @@ GetPersonalData &lt;&lt;RECORD001
 Bozo
 Bozeman
 2726 Nondescript Dr.
-Baltimore
-MD
+Bozeman
+MT
 21226
 RECORD001
 
