@@ -6,8 +6,8 @@
 # =================================================================
 #                 Standard Check for Script Argument(s)
 ARGS=1
-E_BADARGS=65
-E_NOFILE=66
+E_BADARGS=85
+E_NOFILE=86
 
 if [ $# -ne $ARGS ]  # Correct number of arguments passed to script?
 then
@@ -22,17 +22,18 @@ else
     echo "File \"$1\" does not exist."
     exit $E_NOFILE
 fi
-# =================================================================
+# -----------------------------------------------------------------
 
 MAXWIDTH=70          # Width to fold excessively long lines to.
 
-# ---------------------------------
+# =================================
 # A variable can hold a sed script.
+# It's a useful technique.
 sedscript='s/^>//
 s/^  *>//
 s/^  *//
 s/		*//'
-# ---------------------------------
+# =================================
 
 #  Delete carets and tabs at beginning of lines,
 #+ then fold lines to $MAXWIDTH characters.
@@ -45,6 +46,7 @@ sed "$sedscript" $1 | fold -s --width=$MAXWIDTH
 #+ extolling a 164K MS Windows utility with similar functionality.
 #
 #  An nice set of text processing utilities and an efficient
-#+ scripting language provide an alternative to bloated executables.
+#+ scripting language provide an alternative to the bloated executables
+#+ of a clunky operating system.
 
-exit
+exit $?
